import { FC } from 'react';
import classNames from 'classnames';
import { Popover, PopoverProps } from '@servicetitan/design-system';
import * as Styles from '../feature-spotlight.module.css';

export interface FeaturePopoverProps extends PopoverProps {
    footer?: PopoverProps['footer'];
    header?: PopoverProps['header'];
    children?: PopoverProps['children'];
}

export const FeaturePopover: FC<FeaturePopoverProps> = ({ children, footer, header, ...rest }) => {
    return (
        <Popover
            className={classNames(Styles.featurePopover)}
            caret={{ show: true, className: Styles.featurePopoverCaret }}
            padding="m"
            {...rest}
        >
            {header && (
                <Popover.Header className={classNames(Styles.featurePopoverHeader)}>
                    {header}
                </Popover.Header>
            )}
            {children}
            {footer && (
                <Popover.Footer className={classNames(Styles.featurePopoverFooter)} align="right">
                    {footer}
                </Popover.Footer>
            )}
        </Popover>
    );
};
